Enum ion_binary_rs::IonParserError [−][src]
pub enum IonParserError {
Show variants
Unimplemented,
NullAnnotationFound,
NestedAnnotations,
BadAnnotationLength,
SharedTableAndLocalTableDeclarationIntTheSameAnnotation,
SymbolIdNotDefined,
LocalTableWithoutInternalStruct,
SharedTableDefinitionWithoutName,
ErrorAddingSharedTableToContext(SymbolContextError),
ErrorAddingCreatingLocal(SymbolContextError),
LocalSymbolTableWithoutValidImport,
SymbolNotFoundInTable,
ListLengthWasTooShort,
NonUtf8String,
DidNotGetAListConsumingAListThisIsABug,
SymbolIdTooBig,
TableVersionTooBig,
DateValueTooBig,
DateSecondFractionOverflow,
DateNegativeSecondFraction,
DateWithHourButNoMinutes,
ValueLenTooBig,
NotValidLengthFloat,
BinaryError(ParsingError),
DecimalExponentTooBig,
InvalidBoolLength(ValueLength),
InvalidDate(i32, u32, u32, u32, u32, u32, u32),
InvalidReservedTypeDescriptor,
InvalidNegativeInt,
EmptyOrderedStruct,
ValueExtractionFailure(IonExtractionError),
NumericValueDoNotFiti64(TryFromBigIntError<BigInt>),
DecimalNotANumericValue(f64),
TypeNotSupported(IonValue),
}Expand description
Indicated a problem in the binary blob internal structure. When all data is read the library will return IonParserError::BinaryError(ParsingError::NoDataToRead).
Variants
ErrorAddingCreatingLocal(SymbolContextError)BinaryError(ParsingError)ValueExtractionFailure(IonExtractionError)NumericValueDoNotFiti64(TryFromBigIntError<BigInt>)DecimalNotANumericValue(f64)TypeNotSupported(IonValue)Trait Implementations
Performs the conversion.
Performs the conversion.
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.