Enum ion_binary_rs::ParsingError [−][src]
pub enum ParsingError {
InvalidHeaderType,
InvalidHeaderLength,
NoDataToRead,
NotEnoughtDataToRead(usize),
ErrorReadingData(String),
CannotReadZeroBytes,
BadFormedVersionHeader,
InvalidNullLength(ValueLength),
InvalidAnnotationLength(ValueLength),
ThisIsABugConsumingVarUInt,
ThisIsABugConsumingVarInt,
}Expand description
This errors indicate a problem in a primitive parsing. It comes always wrapped by the “BinaryError” of the error type “IonParserError”.
Variants
NotEnoughtDataToRead(usize)ErrorReadingData(String)Trait Implementations
Performs the conversion.
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.